projectal.dynamic_enums.currency_list API documentation

# projectal.dynamic_enums.currency_list

View Source

    1from projectal.dynamic_enum import DynamicEnum
    2
    3
    4class CurrencyList(DynamicEnum):
    5    _name = "CurrencyEnum"

class CurrencyList(projectal.dynamic_enum.DynamicEnum): View Source

    5class CurrencyList(DynamicEnum):
    6    _name = "CurrencyEnum"

##### Inherited Members

projectal.dynamic_enum.DynamicEnum
  get
  set